BEGIN TRANSACTION;
CREATE TABLE metadata
(
 var_name varchar(63) not null,
 var_value varchar(255) not null,
 PRIMARY KEY(var_name)
) ;
CREATE TABLE config
(
 var_name varchar(63) not null,
 var_value varchar(255) null,
 is_visible integer not null default 1,
 need_server_restart integer not null default 0,
 PRIMARY KEY(var_name)
) ;
CREATE TABLE config_clob
(
 var_name varchar(63) not null,
 var_value varchar not null,
 PRIMARY KEY(var_name)
) ;
CREATE TABLE users
(
 id integer not null,
 guid varchar(36) not null,
 name varchar(63) not null,
 password varchar(48) not null,
 system_access integer not null,
 flags integer not null,
 full_name varchar(127) not null,
 description varchar(255) not null,
 grace_logins integer not null,
 auth_method integer not null,
 cert_mapping_method integer not null,
 cert_mapping_data varchar not null,
 auth_failures integer not null,
 last_passwd_change integer not null,
 min_passwd_length integer not null,
 disabled_until integer not null,
 last_login integer not null,
 password_history varchar null,
 PRIMARY KEY(id)
) ;
CREATE TABLE user_groups
(
 id integer not null,
 guid varchar(36) not null,
 name varchar(63) not null,
 system_access integer not null,
 flags integer not null,
 description varchar(255) not null,
 PRIMARY KEY(id)
) ;
CREATE TABLE user_group_members
(
 group_id integer not null,
 user_id integer not null,
 PRIMARY KEY(group_id,user_id)
) ;
CREATE TABLE user_profiles
(
 user_id integer not null,
 var_name varchar(255) not null,
 var_value varchar not null,
 PRIMARY KEY(user_id,var_name)
) ;
CREATE TABLE userdb_custom_attributes
(
 object_id integer not null,
 attr_name varchar(255) not null,
 attr_value varchar not null,
 PRIMARY KEY(object_id,attr_name)
) ;
CREATE TABLE object_properties
(
 object_id integer not null,
 guid varchar(36) not null,
 name varchar(63) not null,
 status integer not null,
 is_deleted integer not null,
 is_system integer not null,
 last_modified integer not null,
 inherit_access_rights integer not null,
 status_calc_alg integer not null,
 status_prop_alg integer not null,
 status_fixed_val integer not null,
 status_shift integer not null,
 status_translation varchar(8) not null,
 status_single_threshold integer not null,
 status_thresholds varchar(8) not null,
 comments varchar null,
 location_type integer not null,
 latitude varchar(20),
 longitude varchar(20),
 image varchar(36) not null,
 submap_id integer not null,
 PRIMARY KEY(object_id)
) ;
CREATE TABLE object_custom_attributes
(
 object_id integer not null,
 attr_name varchar(127) not null,
 attr_value varchar null,
 PRIMARY KEY(object_id,attr_name)
) ;
CREATE INDEX idx_ocattr_oid ON object_custom_attributes(object_id);
CREATE TABLE zones
(
 id integer not null,
 zone_guid integer not null,
 agent_proxy integer not null,
 snmp_proxy integer not null,
 icmp_proxy integer not null,
 PRIMARY KEY(id)
) ;
CREATE TABLE mobile_devices
(
 id integer not null,
 device_id varchar(64) not null,
 vendor varchar(64) null,
 model varchar(128) null,
 serial_number varchar(64) null,
 os_name varchar(32) null,
 os_version varchar(64) null,
 user_id varchar(64) null,
 battery_level integer not null,
 PRIMARY KEY(id)
) ;
CREATE TABLE nodes
(
 id integer not null,
 primary_name varchar(255) null,
 primary_ip varchar(15) not null,
 node_flags integer not null,
 runtime_flags integer not null,
 snmp_version integer not null,
 snmp_port integer not null,
 community varchar(127) null,
 usm_auth_password varchar(127) null,
 usm_priv_password varchar(127) null,
 usm_methods integer not null,
 snmp_oid varchar(255) null,
 auth_method integer not null,
 secret varchar(64) null,
 agent_port integer not null,
 status_poll_type integer not null,
 agent_version varchar(63) null,
 platform_name varchar(63) null,
 poller_node_id integer not null,
 zone_guid integer not null,
 proxy_node integer not null,
 snmp_proxy integer not null,
 required_polls integer not null,
 uname varchar(255) null,
 use_ifxtable integer not null,
 snmp_sys_name varchar(127) null,
 bridge_base_addr varchar(15) null,
 down_since integer not null,
 PRIMARY KEY(id)
) ;
CREATE TABLE clusters
(
 id integer not null,
 cluster_type integer not null,
 zone_guid integer not null,
 PRIMARY KEY(id)
) ;
CREATE TABLE cluster_members
(
 cluster_id integer not null,
 node_id integer not null,
 PRIMARY KEY(cluster_id,node_id)
) ;
CREATE TABLE cluster_sync_subnets
(
 cluster_id integer not null,
 subnet_addr varchar(15) not null,
 subnet_mask varchar(15) not null,
 PRIMARY KEY(cluster_id,subnet_addr)
) ;
CREATE TABLE cluster_resources
(
 cluster_id integer not null,
 resource_id integer not null,
 resource_name varchar(255),
 ip_addr varchar(15) not null,
 current_owner integer not null,
 PRIMARY KEY(cluster_id,resource_id)
) ;
CREATE TABLE subnets
(
 id integer not null,
 ip_addr varchar(15) not null,
 ip_netmask varchar(15) not null,
 zone_guid integer not null,
 synthetic_mask integer not null,
 PRIMARY KEY(id)
) ;
CREATE TABLE interfaces
(
 id integer not null,
 node_id integer not null,
 flags integer not null,
 ip_addr varchar(15) not null,
 ip_netmask varchar(15) not null,
 if_type integer not null,
 if_index integer not null,
 bridge_port integer not null,
 phy_slot integer not null,
 phy_port integer not null,
 peer_node_id integer not null,
 peer_if_id integer not null,
 mac_addr varchar(15) not null,
 required_polls integer not null,
 admin_state integer not null,
 oper_state integer not null,
 dot1x_pae_state integer not null,
 dot1x_backend_state integer not null,
 description varchar(255),
 PRIMARY KEY(id)
) ;
CREATE TABLE network_services
(
 id integer not null,
 node_id integer not null,
 service_type integer not null,
 ip_bind_addr varchar(15) not null,
 ip_proto integer not null,
 ip_port integer not null,
 check_request varchar null,
 check_responce varchar null,
 poller_node_id integer not null,
 required_polls integer not null,
 PRIMARY KEY(id)
) ;
CREATE TABLE vpn_connectors
(
 id integer not null,
 node_id integer not null,
 peer_gateway integer not null,
 PRIMARY KEY(id)
) ;
CREATE TABLE vpn_connector_networks
(
 vpn_id integer not null,
 network_type integer not null,
 ip_addr varchar(15) not null,
 ip_netmask varchar(15) not null,
 PRIMARY KEY(vpn_id,ip_addr)
) ;
CREATE TABLE containers
(
 id integer not null,
 category integer not null,
 object_class integer not null,
 flags integer not null,
 auto_bind_filter varchar null,
 PRIMARY KEY(id)
) ;
CREATE TABLE conditions
(
 id integer not null,
 activation_event integer not null,
 deactivation_event integer not null,
 source_object integer not null,
 active_status integer not null,
 inactive_status integer not null,
 script varchar not null,
 PRIMARY KEY(id)
) ;
CREATE TABLE cond_dci_map
(
 condition_id integer not null,
 sequence_number integer not null,
 dci_id integer not null,
 node_id integer not null,
 dci_func integer not null,
 num_polls integer not null,
 PRIMARY KEY(condition_id,sequence_number)
) ;
CREATE TABLE templates
(
 id integer not null,
 version integer not null,
 flags integer not null,
 apply_filter varchar null,
 PRIMARY KEY(id)
) ;
CREATE TABLE dct_node_map
(
 template_id integer not null,
 node_id integer not null,
 PRIMARY KEY(template_id,node_id)
) ;
CREATE TABLE nsmap
(
 subnet_id integer not null,
 node_id integer not null,
 PRIMARY KEY(subnet_id,node_id)
) ;
CREATE TABLE container_members
(
 container_id integer not null,
 object_id integer not null,
 PRIMARY KEY(container_id,object_id)
) ;
CREATE TABLE container_categories
(
 category integer not null,
 name varchar(63),
 image_id integer not null,
 description varchar,
 PRIMARY KEY(category)
) ;
CREATE TABLE acl
(
 object_id integer not null,
 user_id integer not null,
 access_rights integer not null,
 PRIMARY KEY(object_id,user_id)
) ;
CREATE TABLE trusted_nodes
(
 source_object_id integer not null,
 target_node_id integer not null,
 PRIMARY KEY(source_object_id,target_node_id)
) ;
CREATE TABLE items
(
 item_id integer not null,
 node_id integer not null,
 template_id integer not null,
 template_item_id integer not null,
 name varchar(255) null,
 description varchar(255) null,
 flags integer not null,
 source integer not null,
 snmp_port integer not null,
 datatype integer not null,
 polling_interval integer not null,
 retention_time integer not null,
 status integer not null,
 snmp_raw_value_type integer not null,
 delta_calculation integer not null,
 transformation varchar,
 instance varchar(255) null,
 system_tag varchar(255) null,
 resource_id integer not null,
 proxy_node integer not null,
 base_units integer not null,
 unit_multiplier integer not null,
 custom_units_name varchar(63),
 perftab_settings varchar,
 PRIMARY KEY(item_id)
) ;
CREATE TABLE dc_tables
(
 item_id integer not null,
 node_id integer not null,
 template_id integer not null,
 template_item_id integer not null,
 name varchar(255) null,
 instance_column varchar(63) null,
 description varchar(255) null,
 flags integer not null,
 source integer not null,
 snmp_port integer not null,
 polling_interval integer not null,
 retention_time integer not null,
 status integer not null,
 system_tag varchar(255) null,
 resource_id integer not null,
 proxy_node integer not null,
 perftab_settings varchar,
 PRIMARY KEY(item_id)
) ;
CREATE TABLE dc_table_columns
(
 table_id integer not null,
 column_name varchar(63) not null,
 snmp_oid varchar(1023) null,
 data_type integer not null,
 transformation_script varchar null,
 PRIMARY KEY(table_id,column_name)
) ;
CREATE TABLE dct_column_names
(
 column_id integer not null,
 column_name varchar(63) not null,
 PRIMARY KEY(column_id)
) ;
CREATE TABLE dci_schedules
(
 schedule_id integer not null,
 item_id integer not null,
 schedule varchar(255) null,
 PRIMARY KEY(item_id,schedule_id)
) ;
CREATE TABLE raw_dci_values
(
 item_id integer not null,
 raw_value varchar(255) null,
 transformed_value varchar(255) null,
 last_poll_time integer not null,
 PRIMARY KEY(item_id)
) ;
CREATE INDEX idx_raw_dci_values_item_id ON raw_dci_values(item_id);
CREATE TABLE event_cfg
(
 event_code integer not null,
 event_name varchar(63) not null,
 severity integer not null,
 flags integer not null,
 message varchar(255) not null,
 description varchar not null,
 PRIMARY KEY(event_code)
) ;
CREATE TABLE event_log
(
 event_id number(20) not null,
 event_code integer not null,
 event_timestamp integer not null,
 event_source integer not null,
 event_severity integer not null,
 event_message varchar(255) null,
 root_event_id number(20) not null,
 user_tag varchar(63) null,
 PRIMARY KEY(event_id)
) ;
CREATE INDEX idx_event_log_event_timestamp ON event_log(event_timestamp);
CREATE INDEX idx_event_log_root_id ON event_log(root_event_id);
CREATE TABLE actions
(
 action_id integer not null,
 action_name varchar(63) not null,
 action_type integer not null,
 is_disabled integer not null,
 rcpt_addr varchar(255) null,
 email_subject varchar(255) null,
 action_data varchar null,
 PRIMARY KEY(action_id)
) ;
CREATE TABLE event_groups
(
 id integer not null,
 name varchar(63) not null,
 description varchar(255) not null,
 range_start integer not null,
 range_end integer not null,
 PRIMARY KEY(id)
) ;
CREATE TABLE event_group_members
(
 group_id integer not null,
 event_code integer not null,
 PRIMARY KEY(group_id,event_code)
) ;
CREATE TABLE event_policy
(
 rule_id integer not null,
 flags integer not null,
 comments varchar not null,
 script varchar not null,
 alarm_message varchar(255) not null,
 alarm_severity integer not null,
 alarm_key varchar(255) not null,
 alarm_timeout integer not null,
 alarm_timeout_event integer not null,
 situation_id integer not null,
 situation_instance varchar(255) not null,
 PRIMARY KEY(rule_id)
) ;
CREATE TABLE policy_source_list
(
 rule_id integer not null,
 object_id integer not null,
 PRIMARY KEY(rule_id,object_id)
) ;
CREATE TABLE policy_event_list
(
 rule_id integer not null,
 event_code integer not null,
 PRIMARY KEY(rule_id,event_code)
) ;
CREATE TABLE policy_action_list
(
 rule_id integer not null,
 action_id integer not null,
 PRIMARY KEY(rule_id,action_id)
) ;
CREATE TABLE policy_time_range_list
(
 rule_id integer not null,
 time_range_id integer not null,
 PRIMARY KEY(rule_id,time_range_id)
) ;
CREATE TABLE policy_situation_attr_list
(
 rule_id integer not null,
 situation_id integer not null,
 attr_name varchar(255) not null,
 attr_value varchar(255) not null,
 PRIMARY KEY(rule_id,situation_id,attr_name)
) ;
CREATE TABLE time_ranges
(
 time_range_id integer not null,
 wday_mask integer not null,
 mday_mask integer not null,
 month_mask integer not null,
 time_range varchar(255) not null,
 PRIMARY KEY(time_range_id)
) ;
CREATE TABLE thresholds
(
 threshold_id integer not null,
 item_id integer not null,
 sequence_number integer not null,
 fire_value varchar(255) null,
 rearm_value varchar(255) null,
 check_function integer not null,
 check_operation integer not null,
 parameter_1 integer not null,
 parameter_2 integer not null,
 event_code integer not null,
 rearm_event_code integer not null,
 repeat_interval integer not null,
 current_state integer not null,
 current_severity integer not null,
 last_event_timestamp integer not null,
 PRIMARY KEY(threshold_id)
) ;
CREATE INDEX idx_thresholds_item_id ON thresholds(item_id);
CREATE INDEX idx_thresholds_sequence ON thresholds(sequence_number);
CREATE TABLE alarms
(
 alarm_id integer not null,
 alarm_state integer not null,
 hd_state integer not null,
 hd_ref varchar(63) null,
 creation_time integer not null,
 last_change_time integer not null,
 source_object_id integer not null,
 source_event_code integer not null,
 source_event_id number(20) not null,
 message varchar(255) null,
 original_severity integer not null,
 current_severity integer not null,
 repeat_count integer not null,
 alarm_key varchar(255) null,
 ack_by integer not null,
 resolved_by integer not null,
 term_by integer not null,
 timeout integer not null,
 timeout_event integer not null,
 PRIMARY KEY(alarm_id)
) ;
CREATE TABLE alarm_notes
(
 note_id integer not null,
 alarm_id integer not null,
 change_time integer not null,
 user_id integer not null,
 note_text varchar null,
 PRIMARY KEY(note_id)
) ;
CREATE INDEX idx_alarm_notes_alarm_id ON alarm_notes(alarm_id);
CREATE TABLE alarm_events
(
 alarm_id integer not null,
 event_id number(20) not null,
 event_code integer not null,
 event_name varchar(63) null,
 severity integer not null,
 source_object_id integer not null,
 event_timestamp integer not null,
 message varchar(255) null,
 PRIMARY KEY(alarm_id,event_id)
) ;
CREATE INDEX idx_alarm_events_alarm_id ON alarm_events(alarm_id);
CREATE TABLE snmp_trap_cfg
(
 trap_id integer not null,
 snmp_oid varchar(255),
 event_code integer not null,
 user_tag varchar(63),
 description varchar(255),
 PRIMARY KEY(trap_id)
) ;
CREATE TABLE snmp_trap_pmap
(
 trap_id integer not null,
 parameter integer not null,
 flags integer not null,
 snmp_oid varchar(255) null,
 description varchar(255) null,
 PRIMARY KEY(trap_id,parameter)
) ;
CREATE TABLE agent_pkg
(
 pkg_id integer not null,
 pkg_name varchar(63),
 version varchar(31),
 platform varchar(63),
 pkg_file varchar(255),
 description varchar(255),
 PRIMARY KEY(pkg_id)
) ;
CREATE TABLE object_tools
(
 tool_id integer not null,
 tool_name varchar(255) not null,
 tool_type integer not null,
 tool_data varchar not null,
 description varchar(255) not null,
 flags integer not null,
 matching_oid varchar(255) not null,
 confirmation_text varchar(255) not null,
 PRIMARY KEY(tool_id)
) ;
CREATE TABLE object_tools_acl
(
 tool_id integer not null,
 user_id integer not null,
 PRIMARY KEY(tool_id,user_id)
) ;
CREATE TABLE object_tools_table_columns
(
 tool_id integer not null,
 col_number integer not null,
 col_name varchar(255),
 col_oid varchar(255),
 col_format integer,
 col_substr integer,
 PRIMARY KEY(tool_id,col_number)
) ;
CREATE TABLE syslog
(
 msg_id number(20) not null,
 msg_timestamp integer not null,
 facility integer not null,
 severity integer not null,
 source_object_id integer not null,
 hostname varchar(127) null,
 msg_tag varchar(32) null,
 msg_text varchar null,
 PRIMARY KEY(msg_id)
) ;
CREATE INDEX idx_syslog_msg_timestamp ON syslog(msg_timestamp);
CREATE TABLE script_library
(
 script_id integer not null,
 script_name varchar(255) not null,
 script_code varchar null,
 PRIMARY KEY(script_id)
) ;
CREATE TABLE snmp_trap_log
(
 trap_id number(20) not null,
 trap_timestamp integer not null,
 ip_addr varchar(15) not null,
 object_id integer not null,
 trap_oid varchar(255) not null,
 trap_varlist varchar null,
 PRIMARY KEY(trap_id)
) ;
CREATE INDEX idx_snmp_trap_log_tt ON snmp_trap_log(trap_timestamp);
CREATE TABLE agent_configs
(
 config_id integer not null,
 config_name varchar(255) not null,
 config_file varchar not null,
 config_filter varchar not null,
 sequence_number integer not null,
 PRIMARY KEY(config_id)
) ;
CREATE TABLE address_lists
(
 list_type integer not null,
 community_id integer not null,
 addr_type integer not null,
 addr1 varchar(15) not null,
 addr2 varchar(15) not null,
 PRIMARY KEY(list_type,community_id,addr_type,addr1,addr2)
) ;
CREATE INDEX idx_address_lists_list_type ON address_lists(list_type);
CREATE TABLE graphs
(
 graph_id integer not null,
 owner_id integer not null,
 name varchar(255) not null,
 config varchar not null,
 PRIMARY KEY(graph_id)
) ;
CREATE TABLE graph_acl
(
 graph_id integer not null,
 user_id integer not null,
 user_rights integer not null,
 PRIMARY KEY(graph_id,user_id)
) ;
CREATE TABLE certificates
(
 cert_id integer not null,
 cert_type integer not null,
 cert_data varchar not null,
 subject varchar not null,
 comments varchar not null,
 PRIMARY KEY(cert_id)
) ;
CREATE TABLE audit_log
(
 record_id integer not null,
 timestamp integer not null,
 subsystem varchar(32) not null,
 success integer not null,
 user_id integer not null,
 workstation varchar(63) not null,
 object_id integer not null,
 message varchar null,
 PRIMARY KEY(record_id)
) ;
CREATE TABLE situations
(
 id integer not null,
 name varchar(127) not null,
 comments varchar not null,
 PRIMARY KEY(id)
) ;
CREATE TABLE snmp_communities
(
 id integer not null,
 community varchar(255) null,
 PRIMARY KEY(id)
) ;
CREATE TABLE ap_common
(
 id integer not null,
 policy_type integer not null,
 version integer not null,
 description varchar null,
 PRIMARY KEY(id)
) ;
CREATE TABLE ap_bindings
(
 policy_id integer not null,
 node_id integer not null,
 PRIMARY KEY(policy_id,node_id)
) ;
CREATE TABLE ap_config_files
(
 policy_id integer not null,
 file_content varchar null,
 PRIMARY KEY(policy_id)
) ;
CREATE TABLE usm_credentials
(
 id integer not null,
 user_name varchar(255) not null,
 auth_method integer not null,
 priv_method integer not null,
 auth_password varchar(255),
 priv_password varchar(255),
 PRIMARY KEY(id)
) ;
CREATE TABLE network_maps
(
 id integer not null,
 map_type integer not null,
 layout integer not null,
 seed integer not null,
 radius integer not null,
 background varchar(36) null,
 bg_latitude varchar(20) null,
 bg_longitude varchar(20) null,
 bg_zoom integer null,
 flags integer not null,
 bg_color integer not null,
 link_color integer not null,
 link_routing integer not null,
 PRIMARY KEY(id)
) ;
CREATE TABLE network_map_elements
(
 map_id integer not null,
 element_id integer not null,
 element_type integer not null,
 element_data varchar not null,
 PRIMARY KEY(map_id,element_id)
) ;
CREATE TABLE network_map_links
(
 map_id integer not null,
 element1 integer not null,
 element2 integer not null,
 link_type integer not null,
 link_name varchar(255) null,
 connector_name1 varchar(63) null,
 connector_name2 varchar(63) null,
 color integer not null,
 status_object integer not null,
 routing integer not null,
 bend_points varchar(4000) null,
 PRIMARY KEY(map_id,element1,element2)
) ;
CREATE TABLE images
(
   guid varchar(36) not null,
   name varchar(255) not null,
   category varchar(255) not null,
   mimetype varchar(32) not null,
   protected integer default 0,
   PRIMARY KEY(guid),
   UNIQUE(name, category)
) ;
CREATE TABLE dashboards
(
 id integer not null,
 num_columns integer not null,
 options integer not null,
 PRIMARY KEY(id)
) ;
CREATE TABLE dashboard_elements
(
 dashboard_id integer not null,
 element_id integer not null,
 element_type integer not null,
 element_data varchar null,
 layout_data varchar null,
 PRIMARY KEY(dashboard_id,element_id)
) ;
CREATE TABLE business_services
(
     service_id integer not null,
     PRIMARY KEY(service_id)
) ;
CREATE TABLE slm_checks
(
     id integer not null,
     type integer not null,
     content varchar null,
     threshold_id integer not null,
     reason varchar(255) null,
     is_template integer not null,
     template_id integer not null,
     current_ticket integer not null,
     PRIMARY KEY(id)
) ;
CREATE TABLE node_links
(
     nodelink_id integer not null,
     node_id integer not null,
     PRIMARY KEY(nodelink_id)
) ;
CREATE TABLE slm_agreements
(
     agreement_id integer not null,
     service_id integer not null,
     org_id integer not null,
     uptime varchar(63) not null,
     period integer not null,
     start_date integer not null,
     notes varchar(255),
     PRIMARY KEY(agreement_id)
) ;
CREATE TABLE slm_tickets
(
     ticket_id integer not null,
     service_id integer not null,
     check_id integer not null,
     create_timestamp integer not null,
     close_timestamp integer not null,
     reason varchar(255) null,
     PRIMARY KEY(ticket_id)
) ;
CREATE TABLE slm_service_history
(
     record_id integer not null,
     service_id integer not null,
     change_timestamp integer not null,
     new_status integer not null,
  PRIMARY KEY(record_id)
) ;
CREATE TABLE organizations
(
     id integer not null,
   parent_id integer not null,
   org_type integer not null,
     name varchar(63) not null,
     description varchar(255),
   manager integer not null,
     PRIMARY KEY(id)
) ;
CREATE TABLE persons
(
 id integer not null,
 org_id integer not null,
 first_name varchar(63),
 last_name varchar(63),
 title varchar(255),
 status integer not null,
 PRIMARY KEY(id)
) ;
CREATE TABLE job_history
(
 id integer not null,
 time_created integer not null,
 time_started integer not null,
 time_finished integer not null,
 job_type varchar(127) null,
 description varchar(255) null,
 additional_info varchar(255) null,
 node_id integer not null,
 user_id integer not null,
 status integer not null,
 failure_message varchar(255) null,
 PRIMARY KEY(id)
) ;
CREATE TABLE reports
(
 id integer not null,
 definition varchar null,
 PRIMARY KEY(id)
) ;
CREATE TABLE report_results
(
 report_id integer not null,
 generated integer not null,
 job_id integer not null,
 PRIMARY KEY(report_id, job_id)
) ;
CREATE TABLE licenses
(
 id integer not null,
 content varchar null,
 PRIMARY KEY(id)
) ;
CREATE TABLE mapping_tables
(
 id integer not null,
 name varchar(63) not null,
 flags integer not null,
 description varchar(4000) null,
 PRIMARY KEY(id)
) ;
CREATE TABLE mapping_data
(
 table_id integer not null,
 md_key varchar(63) not null,
 md_value varchar(255) null,
 description varchar(4000) null,
 PRIMARY KEY(table_id,md_key)
) ;
INSERT INTO metadata (var_name,var_value)
 VALUES ('SchemaVersion',268);
INSERT INTO metadata (var_name,var_value)
 VALUES ('Syntax','SQLITE');
INSERT INTO metadata (var_name,var_value)
 VALUES ('IDataTableCreationCommand','CREATE TABLE idata_%d (item_id integer not null,idata_timestamp integer not null,idata_value varchar(255) null)');
INSERT INTO metadata (var_name,var_value)
 VALUES ('IDataIndexCreationCommand_0','CREATE INDEX idx_idata_%d_id_timestamp ON idata_%d(item_id,idata_timestamp)');
INSERT INTO metadata (var_name,var_value)
 VALUES ('TDataTableCreationCommand','CREATE TABLE tdata_%d (item_id integer not null,tdata_timestamp integer not null,tdata_row integer not null,tdata_column integer not null,tdata_value varchar(255) null)');
INSERT INTO metadata (var_name,var_value)
 VALUES ('TDataIndexCreationCommand_0','CREATE INDEX idx_tdata_%d_id_timestamp ON tdata_%d(item_id,tdata_timestamp)');
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('DBLockStatus','UNLOCKED',0,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('DBLockInfo','',0,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('DBLockPID','0',0,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('ServerID','',0,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('FirstFreeObjectId','100',0,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('EnableZoning','0',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('SyncInterval','60',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('DiscoveryPollingInterval','900',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('StatusPollingInterval','60',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('ConfigurationPollingInterval','3600',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('RoutingTableUpdateInterval','300',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('ConditionPollingInterval','60',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('ResolveNodeNames','1',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('NumberOfBusinessServicePollers','10',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('ClientListenerPort','4701',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('NumberOfDataCollectors','25',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('NumberOfStatusPollers','25',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('NumberOfConfigurationPollers','10',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('NumberOfDiscoveryPollers','1',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('NumberOfRoutingTablePollers','10',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('NumberOfTopologyTablePollers','10',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('NumberOfConditionPollers','10',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('RunNetworkDiscovery','0',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('ActiveNetworkDiscovery','0',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('ActiveDiscoveryInterval','7200',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('DiscoveryFilterFlags','0',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('DiscoveryFilter','none',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('EnableAdminInterface','1',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('EventLogRetentionTime','90',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('HouseKeepingInterval','3600',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('DeleteEmptySubnets','0',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('EnableSNMPTraps','1',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('SMSDriver','<none>',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('SMSDrvConfig','',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('SMTPServer','localhost',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('SMTPFromAddr','netxms@localhost',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('SMTPFromName','NetXMS Server',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('AgentUpgradeWaitTime','600',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('NumberOfUpgradeThreads','10',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('KeepAliveInterval','60',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('DefaultEncryptionPolicy','1',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('AllowedCiphers','31',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('EnableMultipleDBConnections','1',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('NumberOfDatabaseWriters','1',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('IcmpPingSize','46',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('EnableSyslogDaemon','0',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('SyslogListenPort','514',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('SyslogRetentionTime','90',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('StatusCalculationAlgorithm','1',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('StatusPropagationAlgorithm','1',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('FixedStatusValue','0',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('StatusShift','0',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('StatusTranslation','01020304',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('StatusSingleThreshold','75',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('StatusThresholds','503C2814',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('CapabilityExpirationTime','604800',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('DefaultCommunityString','public',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('LogAllSNMPTraps','0',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('DisableVacuum','0',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('LockTimeout','60000',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('RADIUSServer','none',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('RADIUSSecret','netxms',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('RADIUSPort','1645',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('RADIUSSecondaryServer','none',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('RADIUSSecondarySecret','netxms',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('RADIUSSecondaryPort','1645',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('RADIUSNumRetries','5',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('RADIUSTimeout','3',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('MailEncoding','iso-8859-1',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('WindowsConsoleUpgradeURL','http://www.netxms.org/download/netxms-%version%.exe',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('InternalCA','0',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('SNMPRequestTimeout','2000',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('AgentCommandTimeout','4000',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('TopologyExpirationTime','900',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('TopologyDiscoveryRadius','3',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('AuditLogRetentionTime','90',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('EnableAuditLog','1',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('ThresholdRepeatInterval','0',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('PollCountForStatusChange','1',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('AllowDirectSMS','0',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('EnableEventStormDetection','0',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('EventStormEventsPerSecond','100',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('EventStormDuration','15',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('UseInterfaceAliases','0',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('SyncNodeNamesWithDNS','0',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('BeaconHosts','',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('BeaconTimeout','1000',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('BeaconPollingInterval','1000',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('CheckTrustedNodes','1',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('EnableAgentRegistration','1',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('AnonymousFileAccess','0',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('EnableISCListener','0',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('ReceiveForwardedEvents','0',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('UseIfXTable','1',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('SMTPRetryCount','1',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('ConnectionPoolBaseSize','5',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('ConnectionPoolMaxSize','20',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('ConnectionPoolCooldownTime','300',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('ExternalAuditServer','none',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('ExternalAuditPort','514',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('ExternalAuditFacility','13',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('ExternalAuditSeverity','5',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('ExternalAuditTag','netxmsd-audit',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('PasswordHistoryLength','0',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('IntruderLockoutThreshold','0',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('IntruderLockoutTime','30',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('MinPasswordLength','0',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('PasswordComplexity','0',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('PasswordExpiration','0',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('BlockInactiveUserAccounts','0',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('AllowTrapVarbindsConversion','1',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('TileServerURL','http://tile.openstreetmap.org/',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('JobHistoryRetentionTime','90',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('AlarmHistoryRetentionTime','180',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('UseDNSNameForDiscoveredNodes','0',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('EnableNXSLContainerFunctions','1',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('DefaultConsoleDateFormat','dd.MM.yyyy',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('DefaultConsoleTimeFormat','HH:mm:ss',1,0);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('DeleteUnreachableNodesPeriod','0',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('UseFQDNForNodeNames','1',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('ApplyDCIFromTemplateToDisabledDCI','0',1,1);
INSERT INTO config (var_name,var_value,is_visible,need_server_restart)
 VALUES ('MobileDeviceListenerPort','4747',1,1);
INSERT INTO users (id,name,password,system_access,flags,full_name,
                   description,grace_logins,auth_method,guid,
                   cert_mapping_method,cert_mapping_data,
                   auth_failures,last_passwd_change,min_passwd_length,
                   disabled_until,last_login)
   VALUES (0,'admin',
           '3A445C0072CD69D9030CC6644020E5C4576051B1',
           65535,8,'#00','Built-in system administrator account',5,0,
           '00000000-0000-0000-0000-000000000000',0,'#00',0,0,0,0,0
          );
INSERT INTO user_groups (id,name,system_access,flags,description,guid)
   VALUES (-2147483648, 'Everyone', 16, 0, 'Built-in everyone group',
           '00000000-0000-0000-0000-000000000000'
          );
INSERT INTO user_groups (id,name,system_access,flags,description,guid)
   VALUES (-2147483647, 'Admins', 65535, 0, 'Default administrative group',
           '00000000-0000-0000-0000-000000000000'
          );
INSERT INTO acl (object_id,user_id,access_rights) VALUES (1,-2147483647,2047);
INSERT INTO acl (object_id,user_id,access_rights) VALUES (2,-2147483647,2047);
INSERT INTO acl (object_id,user_id,access_rights) VALUES (3,-2147483647,2047);
INSERT INTO acl (object_id,user_id,access_rights) VALUES (4,-2147483647,2047);
INSERT INTO acl (object_id,user_id,access_rights) VALUES (5,-2147483647,2047);
INSERT INTO acl (object_id,user_id,access_rights) VALUES (6,-2147483647,2047);
INSERT INTO acl (object_id,user_id,access_rights) VALUES (7,-2147483647,2047);
INSERT INTO acl (object_id,user_id,access_rights) VALUES (8,-2147483647,2047);
INSERT INTO acl (object_id,user_id,access_rights) VALUES (9,-2147483647,2047);
INSERT INTO event_groups (id,name,description,range_start,range_end)
   VALUES (-2147483647,'NodeStatus','All events reporting about node status change',0,0);
INSERT INTO event_groups (id,name,description,range_start,range_end)
   VALUES (-2147483646,'NewObjects','All events reporting about new objects creation',0,0);
INSERT INTO event_group_members (group_id,event_code) VALUES (-2147483647,6);
INSERT INTO event_group_members (group_id,event_code) VALUES (-2147483647,8);
INSERT INTO event_group_members (group_id,event_code) VALUES (-2147483647,7);
INSERT INTO event_group_members (group_id,event_code) VALUES (-2147483647,9);
INSERT INTO event_group_members (group_id,event_code) VALUES (-2147483647,10);
INSERT INTO event_group_members (group_id,event_code) VALUES (-2147483647,11);
INSERT INTO event_group_members (group_id,event_code) VALUES (-2147483647,12);
INSERT INTO event_group_members (group_id,event_code) VALUES (-2147483646,1);
INSERT INTO event_group_members (group_id,event_code) VALUES (-2147483646,2);
INSERT INTO event_group_members (group_id,event_code) VALUES (-2147483646,3);
INSERT INTO container_categories (category,name,image_id,description)
   VALUES (1,'Group',0,'Generic object group');
INSERT INTO container_categories (category,name,image_id,description)
   VALUES (2,'Location',0,'Geografic location');
INSERT INTO container_categories (category,name,image_id,description)
   VALUES (3,'Service',0,'Logical service');
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  1, 'SYS_NODE_ADDED',
  0, 1,
  'Node added',
  'Generated when new node object added to the database.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   No message-specific parameters'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  2, 'SYS_SUBNET_ADDED',
  0, 0,
  'Subnet added',
  'Generated when new subnet object added to the database.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   No message-specific parameters'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  3, 'SYS_IF_ADDED',
  0, 1,
  'Interface "%2" added (IP Addr: %3/%4, IfIndex: %5)',
  'Generated when new interface object added to the database.#0D#0A' ||
  'Please note that source of event is node, not an interface itself.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Interface object ID#0D#0A' ||
  '   2) Interface name#0D#0A' ||
  '   3) Interface IP address#0D#0A' ||
  '   4) Interface netmask#0D#0A' ||
  '   5) Interface index'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  4, 'SYS_IF_UP',
  0, 1,
  'Interface "%2" changed state to UP (IP Addr: %3/%4, IfIndex: %5)',
  'Generated when interface goes up.#0D#0A' ||
  'Please note that source of event is node, not an interface itself.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Interface object ID#0D#0A' ||
  '   2) Interface name#0D#0A' ||
  '   3) Interface IP address#0D#0A' ||
  '   4) Interface netmask#0D#0A' ||
  '   5) Interface index'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  5, 'SYS_IF_DOWN',
  2, 1,
  'Interface "%2" changed state to DOWN (IP Addr: %3/%4, IfIndex: %5)',
  'Generated when interface goes down.#0D#0A' ||
  'Please note that source of event is node, not an interface itself.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Interface object ID#0D#0A' ||
  '   2) Interface name#0D#0A' ||
  '   3) Interface IP address#0D#0A' ||
  '   4) Interface netmask#0D#0A' ||
  '   5) Interface index'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  45, 'SYS_IF_UNKNOWN',
  1, 1,
  'Interface "%2" changed state to UNKNOWN (IP Addr: %3/%4, IfIndex: %5)',
  'Generated when interface goes to unknown state.#0D#0A' ||
  'Please note that source of event is node, not an interface itself.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Interface object ID#0D#0A' ||
  '   2) Interface name#0D#0A' ||
  '   3) Interface IP address#0D#0A' ||
  '   4) Interface netmask#0D#0A' ||
  '   5) Interface index'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  46, 'SYS_IF_DISABLED',
  0, 1,
  'Interface "%2" disabled (IP Addr: %3/%4, IfIndex: %5)',
  'Generated when interface administratively disabled.#0D#0A' ||
  'Please note that source of event is node, not an interface itself.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Interface object ID#0D#0A' ||
  '   2) Interface name#0D#0A' ||
  '   3) Interface IP address#0D#0A' ||
  '   4) Interface netmask#0D#0A' ||
  '   5) Interface index'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  47, 'SYS_IF_TESTING',
  0, 1,
  'Interface "%2" is testing (IP Addr: %3/%4, IfIndex: %5)',
  'Generated when interface goes to testing state.#0D#0A' ||
  'Please note that source of event is node, not an interface itself.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Interface object ID#0D#0A' ||
  '   2) Interface name#0D#0A' ||
  '   3) Interface IP address#0D#0A' ||
  '   4) Interface netmask#0D#0A' ||
  '   5) Interface index'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  62, 'SYS_IF_UNEXPECTED_UP',
  3, 1,
  'Interface "%2" unexpectedly changed state to UP (IP Addr: %3/%4, IfIndex: %5)',
  'Generated when interface goes up but it''s expected state set to DOWN.#0D#0A' ||
  'Please note that source of event is node, not an interface itself.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Interface object ID#0D#0A' ||
  '   2) Interface name#0D#0A' ||
  '   3) Interface IP address#0D#0A' ||
  '   4) Interface netmask#0D#0A' ||
  '   5) Interface index'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  63, 'SYS_IF_EXPECTED_DOWN',
  0, 1,
  'Interface "%2" with expected state DOWN changed state to DOWN (IP Addr: %3/%4, IfIndex: %5)',
  'Generated when interface goes down and it''s expected state is DOWN.#0D#0A' ||
  'Please note that source of event is node, not an interface itself.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Interface object ID#0D#0A' ||
  '   2) Interface name#0D#0A' ||
  '   3) Interface IP address#0D#0A' ||
  '   4) Interface netmask#0D#0A' ||
  '   5) Interface index'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  6, 'SYS_NODE_NORMAL',
  0, 1,
  'Node status changed to NORMAL',
  'Generated when node status changed to normal.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Previous node status'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  7, 'SYS_NODE_WARNING',
  1, 1,
  'Node status changed to WARNING',
  'Generated when node status changed to "Warning".#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Previous node status'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  8, 'SYS_NODE_MINOR',
  2, 1,
  'Node status changed to MINOR',
  'Generated when node status changed to "Minor Problem" (informational).#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Previous node status'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  9, 'SYS_NODE_MAJOR',
  3, 1,
  'Node status changed to MAJOR',
  'Generated when node status changed to "Major Problem".#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Previous node status'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  10, 'SYS_NODE_CRITICAL',
  4, 1,
  'Node status changed to CRITICAL',
  'Generated when node status changed to critical.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Previous node status'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  11, 'SYS_NODE_UNKNOWN',
  0, 1,
  'Node status changed to UNKNOWN',
  'Generated when node status changed to unknown.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Previous node status'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  12, 'SYS_NODE_UNMANAGED',
  0, 1,
  'Node status changed to UNMANAGED',
  'Generated when node status changed to unmanaged.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Previous node status'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  13, 'SYS_NODE_CAP_CHANGED',
  0, 0,
  'Node capabilities changed (Old: %1; New: %2)',
  'Generated when node capabilities changed.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Old capabilities#0D#0A' ||
  '   2) New capabilities'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  14, 'SYS_SNMP_UNREACHABLE',
  1, 1,
  'SNMP agent is not responding',
  'Generated when node#27s SNMP agent is not responding.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   No message-specific parameters'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  15, 'SYS_AGENT_UNREACHABLE',
  1, 1,
  'Native agent is not responding',
  'Generated when node#27s native agent is not responding.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   No message-specific parameters'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  16, 'SYS_IF_DELETED',
  0, 1,
  'Interface "%2" deleted (IP Addr: %3/%4, IfIndex: %1)',
  'Generated when interface object deleted from the database.#0D#0A' ||
  'Please note that source of event is node, not an interface itself.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Interface index#0D#0A' ||
  '   2) Interface name#0D#0A' ||
  '   3) Interface IP address#0D#0A' ||
  '   4) Interface netmask'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  17, 'SYS_THRESHOLD_REACHED',
  1, 1,
  'Threshold reached for data collection item #22%2#22 (Parameter: %1; Threshold value: %3; Actual value: %4)',
  'Generated when threshold value reached for specific data collection item.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Parameter name#0D#0A   2) Item description#0D#0A   3) Threshold value#0D#0A   4) Actual value#0D#0A   5) Data collection item ID#0D#0A   6) Instance#0D#0A   7) Repeat flag'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  18, 'SYS_THRESHOLD_REARMED',
  0, 1,
  'Threshold rearmed for data collection item %2 (Parameter: %1)',
  'Generated when threshold check is rearmed for specific data collection item.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Parameter name#0D#0A' ||
  '   2) Item description#0D#0A' ||
  '   3) Data collection item ID#0D#0A' ||
  '   4) Instance#0D#0A' ||
  '   5) Threshold value#0D#0A' ||
  '   6) Actual value'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  19, 'SYS_SUBNET_DELETED',
  0, 0,
  'Subnet deleted',
  'Generated when subnet object deleted from the database.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   No message-specific parameters'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  20, 'SYS_THREAD_HANG',
  4, 1,
  'Thread "%1" is not responding',
  'Generated when one of the system threads hangs or stops unexpectedly.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Thread name'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  21, 'SYS_THREAD_RUNNING',
  0, 1,
  'Thread "%1" was returned to running state',
  'Generated when one of the system threads which previously hangs or stops unexpectedly was returned to running state.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Thread name'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  22, 'SYS_SMTP_FAILURE',
  1, 1,
  'Unable to send e-mail to <%3>: %2',
  'Generated when server is unable to send e-mail.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Error code#0D#0A' ||
  '   2) Error text#0D#0A' ||
  '   3) Recipient address#0D#0A' ||
  '   4) Mail subject'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  23, 'SYS_MAC_ADDR_CHANGED',
  1, 1,
  'MAC address for interface %3 changed from %4 to %5',
  'Generated when server detects change of interface#27s MAC address.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Interface object ID#0D#0A' ||
  '   2) Interface index#0D#0A' ||
  '   3) Interface name#0D#0A' ||
  '   4) Old MAC address#0D#0A' ||
  '   5) New MAC address'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  24, 'SYS_INCORRECT_NETMASK',
  2, 1,
  'Invalid network mask %4 on interface "%3", should be %5',
  'Generated when server detects invalid network mask on an interface.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Interface object ID#0D#0A' ||
  '   2) Interface index#0D#0A' ||
  '   3) Interface name#0D#0A' ||
  '   4) Actual network mask on interface#0D#0A' ||
  '   5) Correct network mask'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  28, 'SYS_NODE_DOWN',
  4, 1,
  'Node down',
  'Generated when node is not responding to management server.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   No event-specific parameters'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  29, 'SYS_NODE_UP',
  0, 1,
  'Node up',
  'Generated when communication with the node re-established.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   No event-specific parameters'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  25, 'SYS_SERVICE_DOWN',
  3, 1,
  'Network service "%1" is not responding',
  'Generated when network service is not responding to management server as expected.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Service name#0D#0A' ||
  '   2) Service object ID#0D#0A' ||
  '   3) Service type'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  26, 'SYS_SERVICE_UP',
  0, 1,
  'Network service "%1" returned to operational state',
  'Generated when network service responds as expected after failure.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Service name#0D#0A' ||
  '   2) Service object ID#0D#0A' ||
  '   3) Service type'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  27, 'SYS_SERVICE_UNKNOWN',
  1, 1,
  'Status of network service "%1" is unknown',
  'Generated when management server is unable to determine state of the network service due to agent or server-to-agent communication failure.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Service name#0D#0A' ||
  '   2) Service object ID#0D#0A' ||
  '   3) Service type'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  30, 'SYS_SMS_FAILURE',
  1, 1,
  'Unable to send SMS to phone %1',
  'Generated when server is unable to send SMS.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Phone number'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  31, 'SYS_SNMP_OK',
  0, 1,
  'Connectivity with SNMP agent restored',
  'Generated when connectivity with node#27s SNMP agent restored.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   No message-specific parameters'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  32, 'SYS_AGENT_OK',
  0, 1,
  'Connectivity with native agent restored',
  'Generated when connectivity with node#27s native agent restored.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   No message-specific parameters'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  33, 'SYS_SCRIPT_ERROR',
  2, 1,
  'Script (%1) execution error: %2',
  'Generated when server encounters NXSL script execution error.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Script name#0D#0A' ||
  '   2) Error text#0D#0A' ||
  '   3) DCI ID if script is DCI transformation script, or 0 otherwise'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  34, 'SYS_CONDITION_ACTIVATED',
  2, 1,
  'Condition "%2" activated',
  'Default event for condition activation.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Condition object ID#0D#0A' ||
  '   2) Condition object name#0D#0A' ||
  '   3) Previous condition status#0D#0A' ||
  '   4) Current condition status'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  35, 'SYS_CONDITION_DEACTIVATED',
  0, 1,
  'Condition "%2" deactivated',
  'Default event for condition deactivation.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Condition object ID#0D#0A' ||
  '   2) Condition object name#0D#0A' ||
  '   3) Previous condition status#0D#0A' ||
  '   4) Current condition status'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  36, 'SYS_DB_CONN_LOST',
  4, 1,
  'Lost connection with backend database engine',
  'Generated if connection with backend database engine is lost.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   No message-specific parameters'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  37, 'SYS_DB_CONN_RESTORED',
  0, 1,
  'Connection with backend database engine restored',
  'Generated when connection with backend database engine restored.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   No message-specific parameters'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  38, 'SYS_CLUSTER_RESOURCE_MOVED',
  1, 1,
  'Cluster resource "%2" moved from node %4 to node %6',
  'Generated when cluster resource moved between nodes.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Resource ID#0D#0A' ||
  '   2) Resource name#0D#0A' ||
  '   3) Previous owner node ID#0D#0A' ||
  '   4) Previous owner node name#0D#0A' ||
  '   5) New owner node ID#0D#0A' ||
  '   6) New owner node name'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  39, 'SYS_CLUSTER_RESOURCE_DOWN',
  3, 1,
  'Cluster resource "%2" is down (last owner was %4)',
  'Generated when cluster resource goes down.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Resource ID#0D#0A' ||
  '   2) Resource name#0D#0A' ||
  '   3) Last owner node ID#0D#0A' ||
  '   4) Last owner node name'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  40, 'SYS_CLUSTER_RESOURCE_UP',
  0, 1,
  'Cluster resource "%2" is up (new owner is %4)',
  'Generated when cluster resource goes up.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Resource ID#0D#0A' ||
  '   2) Resource name#0D#0A' ||
  '   3) New owner node ID#0D#0A' ||
  '   4) New owner node name'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  41, 'SYS_CLUSTER_DOWN',
  4, 1,
  'Cluster is down',
  'Generated when cluster goes down.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   No message-specific parameters'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  42, 'SYS_CLUSTER_UP',
  0, 1,
  'Cluster is up',
  'Generated when cluster goes up.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   No message-specific parameters'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  43, 'SYS_ALARM_TIMEOUT',
  1, 1,
  'Alarm timeout expired (ID: %1; Text: %2)',
  'Generated when alarm timeout expires.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Alarm ID#0D#0A' ||
  '   2) Alarm message#0D#0A' ||
  '   3) Alarm key#0D#0A' ||
  '   4) Original event code'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  44, 'SYS_LOG_RECORD_MATCHED',
  1, 1,
  'Log record matched (Policy: %1; File: %2; Record: %4)',
  'Default event for log record match.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Policy name#0D#0A' ||
  '   2) Log file name#0D#0A' ||
  '   3) Matching regular expression#0D#0A' ||
  '   4) Matched record#0D#0A' ||
  '   5 .. 9) Reserved#0D#0A' ||
  '   10 .. 99) Substrings extracted by regular expression'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  48, 'SYS_EVENT_STORM_DETECTED',
  3, 1,
  'Event storm detected (Events per second: %1)',
  'Generated when system detects an event storm.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Events per second#0D#0A' ||
  '   2) Duration#0D#0A' ||
  '   3) Threshold'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  49, 'SYS_EVENT_STORM_ENDED',
  0, 1,
  'Event storm ended',
  'Generated when system clears event storm condition.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Events per second#0D#0A' ||
  '   2) Duration#0D#0A' ||
  '   3) Threshold'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  50, 'SYS_NETWORK_CONN_LOST',
  4, 1,
  'NetXMS server network connectivity lost',
  'Generated when system detects loss of network connectivity based on beacon probing.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Number of beacons'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  51, 'SYS_NETWORK_CONN_RESTORED',
  0, 1,
  'NetXMS server network connectivity restored',
  'Generated when system detects restoration of network connectivity based on beacon probing.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Number of beacons'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  52, 'SYS_DB_QUERY_FAILED',
  4, 1,
  'Database query failed (Query: %1; Error: %2)',
  'Generated when SQL query to backend database failed.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Query#0D#0A' ||
  '   2) Error message'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  53, 'SYS_DCI_UNSUPPORTED',
  2, 1,
  'Status of DCI %1 (%5: %2) changed to UNSUPPORTED',
  'Generated when DCI status changed to UNSUPPORTED.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) DCI ID#0D#0A' ||
  '   2) DCI Name#0D#0A' ||
  '   3) DCI Description#0D#0A' ||
  '   4) DCI Origin code#0D#0A' ||
  '   5) DCI Origin name'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  54, 'SYS_DCI_DISABLED',
  1, 1,
  'Status of DCI %1 (%5: %2) changed to DISABLED',
  'Generated when DCI status changed to DISABLED.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) DCI ID#0D#0A' ||
  '   2) DCI Name#0D#0A' ||
  '   3) DCI Description#0D#0A' ||
  '   4) DCI Origin code#0D#0A' ||
  '   5) DCI Origin name'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  55, 'SYS_DCI_ACTIVE',
  0, 1,
  'Status of DCI %1 (%5: %2) changed to ACTIVE',
  'Generated when DCI status changed to ACTIVE.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) DCI ID#0D#0A' ||
  '   2) DCI Name#0D#0A' ||
  '   3) DCI Description#0D#0A' ||
  '   4) DCI Origin code#0D#0A' ||
  '   5) DCI Origin name'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  56, 'SYS_IP_ADDRESS_CHANGED',
  1, 1,
  'Primary IP address changed from %2 to %1',
  'Generated when primary IP address changed (usually because of primary name change or DNS change).#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) New IP address#0D#0A' ||
  '   2) Old IP address#0D#0A' ||
  '   3) Primary host name'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  57, 'SYS_8021X_PAE_STATE_CHANGED',
  0, 1,
  'Port %6 PAE state changed from %4 to %2',
  'Generated when switch port PAE state changed.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) New PAE state code#0D#0A' ||
  '   2) New PAE state as text#0D#0A' ||
  '   3) Old PAE state code#0D#0A' ||
  '   4) Old PAE state as text#0D#0A' ||
  '   5) Interface index#0D#0A' ||
  '   6) Interface name'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  58, 'SYS_8021X_BACKEND_STATE_CHANGED',
  0, 1,
  'Port %6 backend authentication state changed from %4 to %2',
  'Generated when switch port backend authentication state changed.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) New backend state code#0D#0A' ||
  '   2) New backend state as text#0D#0A' ||
  '   3) Old backend state code#0D#0A' ||
  '   4) Old backend state as text#0D#0A' ||
  '   5) Interface index#0D#0A' ||
  '   6) Interface name'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  59, 'SYS_8021X_PAE_FORCE_UNAUTH',
  3, 1,
  'Port %2 switched to force unauthorize state',
  'Generated when switch port PAE state changed to FORCE UNAUTHORIZE.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Interface index#0D#0A' ||
  '   2) Interface name'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  60, 'SYS_8021X_AUTH_FAILED',
  3, 1,
  '802.1x authentication failed on port %2',
  'Generated when switch port backend authentication state changed to FAIL.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Interface index#0D#0A' ||
  '   2) Interface name'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  61, 'SYS_8021X_AUTH_TIMEOUT',
  3, 1,
  '802.1x authentication time out on port %2',
  'Generated when switch port backend authentication state changed to TIMEOUT.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Interface index#0D#0A' ||
  '   2) Interface name'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  64, 'SYS_CONTAINER_AUTOBIND',
  0, 1,
  'Node %2 automatically bound to container %4',
  'Generated when node bound to container object by autobind rule.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Node ID#0D#0A' ||
  '   2) Node name#0D#0A' ||
  '   3) Container ID#0D#0A' ||
  '   4) Container name'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  65, 'SYS_CONTAINER_AUTOUNBIND',
  0, 1,
  'Node %2 automatically unbound from container %4',
  'Generated when node unbound from container object by autobind rule.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Node ID#0D#0A' ||
  '   2) Node name#0D#0A' ||
  '   3) Container ID#0D#0A' ||
  '   4) Container name'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  66, 'SYS_TEMPLATE_AUTOAPPLY',
  0, 1,
  'Template %4 automatically applied to node %2',
  'Generated when template applied to node by autoapply rule.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Node ID#0D#0A' ||
  '   2) Node name#0D#0A' ||
  '   3) Template ID#0D#0A' ||
  '   4) Template name'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  67, 'SYS_TEMPLATE_AUTOREMOVE',
  0, 1,
  'Template %4 automatically removed from node %2',
  'Generated when template removed from node by autoapply rule.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Node ID#0D#0A' ||
  '   2) Node name#0D#0A' ||
  '   3) Template ID#0D#0A' ||
  '   4) Template name'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  68, 'SYS_NODE_UNREACHABLE',
  4, 1,
  'Node unreachable because of network failure',
  'Generated when node is unreachable by management server because of network failure.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   No event-specific parameters'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  500, 'SNMP_UNMATCHED_TRAP',
  0, 1,
  'SNMP trap received: %1 (Parameters: %2)',
  'Generated when system receives an SNMP trap without match in trap configuration table#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) SNMP trap OID#0D#0A' ||
  '   2) Trap parameters'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  501, 'SNMP_COLD_START',
  0, 1,
  'System was cold-started',
  'Generated when system receives a coldStart SNMP trap#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) SNMP trap OID'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  502, 'SNMP_WARM_START',
  0, 1,
  'System was warm-started',
  'Generated when system receives a warmStart SNMP trap#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) SNMP trap OID'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  503, 'SNMP_LINK_DOWN',
  3, 1,
  'Link is down (interface index %2)',
  'Generated when system receives a linkDown SNMP trap#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) SNMP trap OID#0D#0A' ||
  '   2) Interface index'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  504, 'SNMP_LINK_UP',
  0, 1,
  'Link is up (interface index %2)',
  'Generated when system receives a linkUp SNMP trap#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) SNMP trap OID#0D#0A' ||
  '   2) Interface index'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  505, 'SNMP_AUTH_FAILURE',
  1, 1,
  'SNMP authentication failure',
  'Generated when system receives an authenticationFailure SNMP trap#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) SNMP trap OID'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  506, 'SNMP_EGP_NEIGHBOR_LOSS',
  1, 1,
  'EGP neighbor loss',
  'Generated when system receives an egpNeighborLoss SNMP trap#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) SNMP trap OID'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  4000, 'DC_HIGH_CPU_UTIL',
  2, 1,
  'CPU utilization exceeds allowed maximum of %3 (Current: %4)',
  'Custom data collection threshold event.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Parameter name#0D#0A   2) Item description#0D#0A   3) Threshold value#0D#0A   4) Actual value#0D#0A   5) Data collection item ID#0D#0A   6) Instance#0D#0A   7) Repeat flag'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  4001, 'DC_HIGH_PROCLOAD',
  2, 1,
  'Processor load average exceeds allowed maximum of %3 (Current: %4)',
  'Custom data collection threshold event.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Parameter name#0D#0A   2) Item description#0D#0A   3) Threshold value#0D#0A   4) Actual value#0D#0A   5) Data collection item ID#0D#0A   6) Instance#0D#0A   7) Repeat flag'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  4002, 'DC_HOST_RESTARTED',
  0, 1,
  'Host was restarted within last 5 minutes',
  'Custom data collection threshold event.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Parameter name#0D#0A   2) Item description#0D#0A   3) Threshold value#0D#0A   4) Actual value#0D#0A   5) Data collection item ID#0D#0A   6) Instance#0D#0A   7) Repeat flag'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  4003, 'DC_AGENT_RESTARTED',
  0, 1,
  'NetXMS agent was restarted within last 5 minutes',
  'Custom data collection threshold event.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Parameter name#0D#0A   2) Item description#0D#0A   3) Threshold value#0D#0A   4) Actual value#0D#0A   5) Data collection item ID#0D#0A   6) Instance#0D#0A   7) Repeat flag'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  4004, 'DC_SERVICE_NOT_RUNNING',
  3, 1,
  'Service #22%6#22 is not running',
  'Custom data collection threshold event.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Parameter name#0D#0A   2) Item description#0D#0A   3) Threshold value#0D#0A   4) Actual value#0D#0A   5) Data collection item ID#0D#0A   6) Instance#0D#0A   7) Repeat flag'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  4005, 'DC_MAILBOX_TOO_LARGE',
  1, 1,
  'Mailbox #22%6#22 exceeds size limit (allowed size: %3; actual size: %4)',
  'Custom data collection threshold event.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Parameter name#0D#0A   2) Item description#0D#0A   3) Threshold value#0D#0A   4) Actual value#0D#0A   5) Data collection item ID#0D#0A   6) Instance#0D#0A   7) Repeat flag'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  4006, 'DC_AGENT_VERSION_CHANGE',
  0, 1,
  'NetXMS agent version was changed from %3 to %4',
  'Custom data collection threshold event.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Parameter name#0D#0A   2) Item description#0D#0A   3) Threshold value#0D#0A   4) Actual value#0D#0A   5) Data collection item ID#0D#0A   6) Instance#0D#0A   7) Repeat flag'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  4007, 'DC_HOSTNAME_CHANGE',
  1, 1,
  'Host name was changed from %3 to %4',
  'Custom data collection threshold event.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Parameter name#0D#0A   2) Item description#0D#0A   3) Threshold value#0D#0A   4) Actual value#0D#0A   5) Data collection item ID#0D#0A   6) Instance#0D#0A   7) Repeat flag'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  4008, 'DC_FILE_CHANGE',
  1, 1,
  'File #22%6#22 was changed',
  'Custom data collection threshold event.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Parameter name#0D#0A   2) Item description#0D#0A   3) Threshold value#0D#0A   4) Actual value#0D#0A   5) Data collection item ID#0D#0A   6) Instance#0D#0A   7) Repeat flag'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  4009, 'DC_HDD_TEMP_WARNING',
  1, 1,
  'Temperature of hard disk %6 is above warning level of %3 (current: %4)',
  'Custom data collection threshold event.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Parameter name#0D#0A   2) Item description#0D#0A   3) Threshold value#0D#0A   4) Actual value#0D#0A   5) Data collection item ID#0D#0A   6) Instance#0D#0A   7) Repeat flag'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  4010, 'DC_HDD_TEMP_MAJOR',
  3, 1,
  'Temperature of hard disk %6 is above %3 (current: %4)',
  'Custom data collection threshold event.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Parameter name#0D#0A   2) Item description#0D#0A   3) Threshold value#0D#0A   4) Actual value#0D#0A   5) Data collection item ID#0D#0A   6) Instance#0D#0A   7) Repeat flag'
 );
INSERT INTO event_cfg (event_code,event_name,severity,flags,message,description) VALUES
 (
  4011, 'DC_HDD_TEMP_CRITICAL',
  4, 1,
  'Temperature of hard disk %6 is above critical level of %3 (current: %4)',
  'Custom data collection threshold event.#0D#0A' ||
  'Parameters:#0D#0A' ||
  '   1) Parameter name#0D#0A   2) Item description#0D#0A   3) Threshold value#0D#0A   4) Actual value#0D#0A   5) Data collection item ID#0D#0A   6) Instance#0D#0A   7) Repeat flag'
 );
INSERT INTO event_policy (rule_id,flags,comments,alarm_message,alarm_severity,alarm_key,script,alarm_timeout,alarm_timeout_event,situation_id,situation_instance)
 VALUES (0,7944,'Show alarm when node is down',
  '%m',5,'NODE_DOWN_%i','#00',0,43,0,'#00');
INSERT INTO event_policy (rule_id,flags,comments,alarm_message,alarm_severity,alarm_key,script,alarm_timeout,alarm_timeout_event,situation_id,situation_instance)
 VALUES (1,7944,'Acknowlege node down alarms when node is up',
  '%m',6,'NODE_DOWN_%i','#00',0,43,0,'#00');
INSERT INTO event_policy (rule_id,flags,comments,alarm_message,alarm_severity,alarm_key,script,alarm_timeout,alarm_timeout_event,situation_id,situation_instance)
 VALUES (2,7944,'Show alarm when network service is down or in unknown state',
  '%m',5,'SERVICE_DOWN_%i_%2','#00',0,43,0,'#00');
INSERT INTO event_policy (rule_id,flags,comments,alarm_message,alarm_severity,alarm_key,script,alarm_timeout,alarm_timeout_event,situation_id,situation_instance)
 VALUES (3,7944,'Acknowlege network service down/unknown alarms when service is up',
  '%m',6,'SERVICE_DOWN_%i_%2','#00',0,43,0,'#00');
INSERT INTO event_policy (rule_id,flags,comments,alarm_message,alarm_severity,alarm_key,script,alarm_timeout,alarm_timeout_event,situation_id,situation_instance)
 VALUES (4,7944,'Show alarm when interface is down',
  '%m',5,'IF_DOWN_%i_%1','#00',0,43,0,'#00');
INSERT INTO event_policy (rule_id,flags,comments,alarm_message,alarm_severity,alarm_key,script,alarm_timeout,alarm_timeout_event,situation_id,situation_instance)
 VALUES (5,7944,'Acknowlege interface down alarms when interface is up',
  '%m',6,'IF_DOWN_%i_%1','#00',0,43,0,'#00');
INSERT INTO event_policy (rule_id,flags,comments,alarm_message,alarm_severity,alarm_key,script,alarm_timeout,alarm_timeout_event,situation_id,situation_instance)
 VALUES (6,7944,'Show alarm when interface is unexpectedly up',
  '%m',5,'IF_UNEXP_UP_%i_%1','#00',0,43,0,'#00');
INSERT INTO event_policy (rule_id,flags,comments,alarm_message,alarm_severity,alarm_key,script,alarm_timeout,alarm_timeout_event,situation_id,situation_instance)
 VALUES (7,7944,'Acknowlege interface unexpectedly up alarms when interface goes down',
  '%m',6,'IF_UNEXP_UP_%i_%1','#00',0,43,0,'#00');
INSERT INTO event_policy (rule_id,flags,comments,alarm_message,alarm_severity,alarm_key,script,alarm_timeout,alarm_timeout_event,situation_id,situation_instance)
 VALUES (8,7944,'Generate alarm when incorrect network mask detected on interface',
  '%m',2,'BAD_NETMASK_%i_%2','#00',0,43,0,'#00');
INSERT INTO event_policy (rule_id,flags,comments,alarm_message,alarm_severity,alarm_key,script,alarm_timeout,alarm_timeout_event,situation_id,situation_instance)
 VALUES (9,7944,'Generate alarm when MAC address change detected on interface',
  '%m',1,'#00','#00',0,43,0,'#00');
INSERT INTO event_policy (rule_id,flags,comments,alarm_message,alarm_severity,alarm_key,script,alarm_timeout,alarm_timeout_event,situation_id,situation_instance)
 VALUES (10,7944,'Generate alarm when server enconters NXSL script execution error',
  '%m',2,'SCRIPT_ERR_%1_%2','#00',0,43,0,'#00');
INSERT INTO event_policy (rule_id,flags,comments,alarm_message,alarm_severity,alarm_key,script,alarm_timeout,alarm_timeout_event,situation_id,situation_instance)
 VALUES (11,7944,'Show alarm when connection with backend database is lost',
  '%m',4,'DB_CONN','#00',0,43,0,'#00');
INSERT INTO event_policy (rule_id,flags,comments,alarm_message,alarm_severity,alarm_key,script,alarm_timeout,alarm_timeout_event,situation_id,situation_instance)
 VALUES (12,7944,'Acknowlege DB connection loss alarm when connection restored',
  '%m',6,'DB_CONN','#00',0,43,0,'#00');
INSERT INTO event_policy (rule_id,flags,comments,alarm_message,alarm_severity,alarm_key,script,alarm_timeout,alarm_timeout_event,situation_id,situation_instance)
 VALUES (13,7944,'Show alarm when DCI status changes to DISABLED or UNSUPPORTED',
  '%m',5,'DCI_STATUS_%i_%1','#00',0,43,0,'#00');
INSERT INTO event_policy (rule_id,flags,comments,alarm_message,alarm_severity,alarm_key,script,alarm_timeout,alarm_timeout_event,situation_id,situation_instance)
 VALUES (14,7944,'Acknowlege DCI status alarms when DCI status returns to ACTIVE',
  '%m',6,'DCI_STATUS_%i_%1','#00',0,43,0,'#00');
INSERT INTO event_policy (rule_id,flags,comments,alarm_message,alarm_severity,alarm_key,script,alarm_timeout,alarm_timeout_event,situation_id,situation_instance)
 VALUES (15,7944,'Generate alarm on threshold violation',
  '%m',5,'DC_THRESHOLD_%i_%5','#00',0,43,0,'#00');
INSERT INTO event_policy (rule_id,flags,comments,alarm_message,alarm_severity,alarm_key,script,alarm_timeout,alarm_timeout_event,situation_id,situation_instance)
 VALUES (16,7944,'Acknowlege threshold violation alarm',
  '%m',6,'DC_THRESHOLD_%i_%3','#00',0,43,0,'#00');
INSERT INTO policy_event_list (rule_id,event_code) VALUES (0,28);
INSERT INTO policy_event_list (rule_id,event_code) VALUES (1,29);
INSERT INTO policy_event_list (rule_id,event_code) VALUES (2,25);
INSERT INTO policy_event_list (rule_id,event_code) VALUES (2,27);
INSERT INTO policy_event_list (rule_id,event_code) VALUES (3,26);
INSERT INTO policy_event_list (rule_id,event_code) VALUES (4,5);
INSERT INTO policy_event_list (rule_id,event_code) VALUES (5,4);
INSERT INTO policy_event_list (rule_id,event_code) VALUES (6,62);
INSERT INTO policy_event_list (rule_id,event_code) VALUES (7,63);
INSERT INTO policy_event_list (rule_id,event_code) VALUES (8,24);
INSERT INTO policy_event_list (rule_id,event_code) VALUES (9,23);
INSERT INTO policy_event_list (rule_id,event_code) VALUES (10,33);
INSERT INTO policy_event_list (rule_id,event_code) VALUES (11,36);
INSERT INTO policy_event_list (rule_id,event_code) VALUES (12,37);
INSERT INTO policy_event_list (rule_id,event_code) VALUES (13,54);
INSERT INTO policy_event_list (rule_id,event_code) VALUES (13,53);
INSERT INTO policy_event_list (rule_id,event_code) VALUES (14,55);
INSERT INTO policy_event_list (rule_id,event_code) VALUES (15,17);
INSERT INTO policy_event_list (rule_id,event_code) VALUES (16,18);
INSERT INTO snmp_trap_cfg (trap_id,snmp_oid,event_code,user_tag,description)
   VALUES (1,'.1.3.6.1.6.3.1.1.5.1',501,'','Generic coldStart trap');
INSERT INTO snmp_trap_cfg (trap_id,snmp_oid,event_code,user_tag,description)
   VALUES (2,'.1.3.6.1.6.3.1.1.5.2',502,'','Generic warmStart trap');
INSERT INTO snmp_trap_cfg (trap_id,snmp_oid,event_code,user_tag,description)
   VALUES (3,'.1.3.6.1.6.3.1.1.5.3',503,'','Generic linkDown trap');
INSERT INTO snmp_trap_cfg (trap_id,snmp_oid,event_code,user_tag,description)
   VALUES (4,'.1.3.6.1.6.3.1.1.5.4',504,'','Generic linkUp trap');
INSERT INTO snmp_trap_cfg (trap_id,snmp_oid,event_code,user_tag,description)
   VALUES (5,'.1.3.6.1.6.3.1.1.5.5',505,'','Generic authenticationFailure trap');
INSERT INTO snmp_trap_cfg (trap_id,snmp_oid,event_code,user_tag,description)
   VALUES (6,'.1.3.6.1.6.3.1.1.5.6',506,'','Generic egpNeighborLoss trap');
INSERT INTO snmp_trap_pmap (trap_id,parameter,flags,snmp_oid,description)
   VALUES (3,1,0,'.1.3.6.1.2.1.2.2.1.1','Interface index');
INSERT INTO snmp_trap_pmap (trap_id,parameter,flags,snmp_oid,description)
   VALUES (4,1,0,'.1.3.6.1.2.1.2.2.1.1','Interface index');
INSERT INTO object_tools (tool_id,tool_name,tool_type,tool_data,flags,matching_oid,description,confirmation_text)
 VALUES (1,'&Shutdown system',1,'System.Shutdown',10,' ','Shutdown target node via NetXMS agent','Host #25OBJECT_NAME#25 (#25OBJECT_IP_ADDR#25) will be shut down. Are you sure?');
INSERT INTO object_tools (tool_id,tool_name,tool_type,tool_data,flags,matching_oid,description,confirmation_text)
 VALUES (2,'&Restart system',1,'System.Restart',10,' ','Restart target node via NetXMS agent','Host #25OBJECT_NAME#25 (#25OBJECT_IP_ADDR#25) will be restarted. Are you sure?');
INSERT INTO object_tools (tool_id,tool_name,tool_type,tool_data,flags,matching_oid,description,confirmation_text)
 VALUES (3,'&Wakeup node',0,'wakeup',0,' ','Wakeup node using Wake-On-LAN magic packet','#00');
INSERT INTO object_tools (tool_id,tool_name,tool_type,tool_data,flags,matching_oid,description,confirmation_text)
 VALUES (4,'Restart &agent',1,'Agent.Restart',10,' ','Restart NetXMS agent on target node','NetXMS agent on host #25OBJECT_NAME#25 (#25OBJECT_IP_ADDR#25) will be restarted. Are you sure?');
INSERT INTO object_tools (tool_id,tool_name,tool_type,tool_data,flags,matching_oid,description,confirmation_text)
 VALUES (5,'&Info->&Switch forwarding database (FDB)',2,'Forwarding database',1,' ','Show switch forwarding database','#00');
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (5,0,'MAC Address','.1.3.6.1.2.1.17.4.3.1.1',4,0);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (5,1,'Port','.1.3.6.1.2.1.17.4.3.1.2',5,0);
INSERT INTO object_tools (tool_id,tool_name,tool_type,tool_data,flags,matching_oid,description,confirmation_text)
 VALUES (6,'&Connect->Open &web browser',4,'http://%OBJECT_IP_ADDR%',0,' ','Open embedded web browser to node','#00');
INSERT INTO object_tools (tool_id,tool_name,tool_type,tool_data,flags,matching_oid,description,confirmation_text)
 VALUES (7,'&Connect->Open &web browser (HTTPS)',4,'https://%OBJECT_IP_ADDR%',0,' ','Open embedded web browser to node using HTTPS','#00');
INSERT INTO object_tools (tool_id,tool_name,tool_type,tool_data,flags,matching_oid,description,confirmation_text)
 VALUES (8,'&Info->&Agent->&Subagent list',3,'Subagent List#7FAgent.SubAgentList#7F^(.*) (.*) (.*) (.*)',2,' ','Show list of loaded subagents','#00');
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (8,0,'Name',' ',0,1);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (8,1,'Version',' ',0,2);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (8,2,'File',' ',0,4);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (8,3,'Module handle',' ',0,3);
INSERT INTO object_tools (tool_id,tool_name,tool_type,tool_data,flags,matching_oid,description,confirmation_text)
 VALUES (9,'&Info->&Agent->Supported &parameters',3,'Supported parameters#7FAgent.SupportedParameters#7F^(.*)',2,' ','Show list of parameters supported by agent','#00');
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (9,0,'Parameter',' ',0,1);
INSERT INTO object_tools (tool_id,tool_name,tool_type,tool_data,flags,matching_oid,description,confirmation_text)
 VALUES (10,'&Info->&Agent->Supported &enums',3,'Supported enums#7FAgent.SupportedEnums#7F^(.*)',2,' ','Show list of enums supported by agent','#00');
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (10,0,'Parameter',' ',0,1);
INSERT INTO object_tools (tool_id,tool_name,tool_type,tool_data,flags,matching_oid,description,confirmation_text)
 VALUES (11,'&Info->&Agent->Supported &actions',3,'Supported actions#7FAgent.ActionList#7F^(.*) (.*) #22(.*)#22.*',2,' ','Show list of actions supported by agent','#00');
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (11,0,'Name',' ',0,1);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (11,1,'Type',' ',0,2);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (11,2,'Data',' ',0,3);
INSERT INTO object_tools (tool_id,tool_name,tool_type,tool_data,flags,matching_oid,description,confirmation_text)
 VALUES (12,'&Info->&Agent->Configured &ICMP targets',3,'Configured ICMP targets#7FICMP.TargetList#7F^(.*) (.*) (.*) (.*) (.*)',2,' ','Show list of actions supported by agent','#00');
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (12,0,'IP Address',' ',0,1);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (12,1,'Name',' ',0,5);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (12,2,'Packet size',' ',0,4);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (12,3,'Last RTT',' ',0,2);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (12,4,'Average RTT',' ',0,3);
INSERT INTO object_tools (tool_id,tool_name,tool_type,tool_data,flags,matching_oid,description,confirmation_text)
 VALUES (13,'&Info->&Process list',3,
                'Process List#7FSystem.ProcessList#7F^([0-9]+) (.*)',2,' ','Show list of currently running processes','#00');
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (13,0,'PID',' ',0,1);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (13,1,'Name',' ',0,2);
INSERT INTO object_tools (tool_id,tool_name,tool_type,tool_data,flags,matching_oid,description,confirmation_text)
 VALUES (14,'&Info->Topology table (Nortel)',2,'Topology table',1,' ','Show topology table (Nortel protocol)','#00');
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (14,0,'Peer IP','.1.3.6.1.4.1.45.1.6.13.2.1.1.3',3,0);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (14,1,'Peer MAC','.1.3.6.1.4.1.45.1.6.13.2.1.1.5',4,0);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (14,2,'Slot','.1.3.6.1.4.1.45.1.6.13.2.1.1.1',1,0);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (14,3,'Port','.1.3.6.1.4.1.45.1.6.13.2.1.1.2',1,0);
INSERT INTO object_tools (tool_id,tool_name,tool_type,tool_data,flags,matching_oid,description,confirmation_text)
 VALUES (15,'&Info->Topology table (CDP)',2,'Topology table',1,' ','Show topology table (CDP)','#00');
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (15,0,'Device ID','.1.3.6.1.4.1.9.9.23.1.2.1.1.6',0,0);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (15,1,'IP Address','.1.3.6.1.4.1.9.9.23.1.2.1.1.4',3,0);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (15,2,'Platform','.1.3.6.1.4.1.9.9.23.1.2.1.1.8',0,0);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (15,3,'Version','.1.3.6.1.4.1.9.9.23.1.2.1.1.5',0,0);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (15,4,'Port','.1.3.6.1.4.1.9.9.23.1.2.1.1.7',0,0);
INSERT INTO object_tools (tool_id,tool_name,tool_type,tool_data,flags,matching_oid,description,confirmation_text)
 VALUES (16,'&Info->Active &user sessions',3,
                'Active User Sessions#7FSystem.ActiveUserSessions#7F^"(.*)" "(.*)" "(.*)"',2,' ','Show list of active user sessions','#00');
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (16,0,'User',' ',0,1);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (16,1,'Terminal',' ',0,2);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (16,2,'From',' ',0,3);
INSERT INTO object_tools (tool_id,tool_name,tool_type,tool_data,flags,matching_oid,description,confirmation_text)
 VALUES (17,'&Info->AR&P cache (SNMP)',2,'ARP Cache',1,' ','Show ARP cache','#00');
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (17,0,'IP Address','.1.3.6.1.2.1.4.22.1.3',3,0);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (17,1,'MAC Address','.1.3.6.1.2.1.4.22.1.2',4,0);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (17,2,'Interface','.1.3.6.1.2.1.4.22.1.1',5,0);
INSERT INTO object_tools (tool_id,tool_name,tool_type,tool_data,flags,matching_oid,description,confirmation_text)
 VALUES (18,'&Info->AR&P cache (Agent)',3,
  'ARP Cache#7FNet.ArpCache#7F(.*) (.*) (.*)',2,' ','Show ARP cache','#00');
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (18,0,'IP Address','.1.3.6.1.2.1.4.22.1.3',0,2);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (18,1,'MAC Address','.1.3.6.1.2.1.4.22.1.2',0,1);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (18,2,'Interface','.1.3.6.1.2.1.4.22.1.1',5,3);
INSERT INTO object_tools (tool_id,tool_name,tool_type,tool_data,flags,matching_oid,description,confirmation_text)
 VALUES (19,'&Info->&Routing table (SNMP)',2,'Routing Table',1,' ','Show IP routing table','#00');
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (19,0,'Destination','.1.3.6.1.2.1.4.21.1.1',3,0);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (19,1,'Mask','.1.3.6.1.2.1.4.21.1.11',3,0);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (19,2,'Next hop','.1.3.6.1.2.1.4.21.1.7',3,0);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (19,3,'Metric','.1.3.6.1.2.1.4.21.1.3',1,0);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (19,4,'Interface','.1.3.6.1.2.1.4.21.1.2',5,0);
INSERT INTO object_tools (tool_id,tool_name,tool_type,tool_data,flags,matching_oid,description,confirmation_text)
 VALUES (20,'&Info->Topology table (LLDP)',2,'Topology Table',1,' ','Show topology table (LLDP)','#00');
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (20,0,'Chassis ID','.1.0.8802.1.1.2.1.4.1.1.5',0,0);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (20,1,'Local port','.1.0.8802.1.1.2.1.4.1.1.2',5,0);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (20,2,'System name','.1.0.8802.1.1.2.1.4.1.1.9',0,0);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (20,3,'System description','.1.0.8802.1.1.2.1.4.1.1.10',0,0);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (20,4,'Remote port ID','.1.0.8802.1.1.2.1.4.1.1.7',4,0);
INSERT INTO object_tools_table_columns (tool_id,col_number,col_name,col_oid,col_format,col_substr)
 VALUES (20,5,'Remote port description','.1.0.8802.1.1.2.1.4.1.1.8',0,0);
INSERT INTO object_tools_acl (tool_id,user_id) VALUES (1,-2147483648);
INSERT INTO object_tools_acl (tool_id,user_id) VALUES (2,-2147483648);
INSERT INTO object_tools_acl (tool_id,user_id) VALUES (3,-2147483648);
INSERT INTO object_tools_acl (tool_id,user_id) VALUES (4,-2147483648);
INSERT INTO object_tools_acl (tool_id,user_id) VALUES (5,-2147483648);
INSERT INTO object_tools_acl (tool_id,user_id) VALUES (6,-2147483648);
INSERT INTO object_tools_acl (tool_id,user_id) VALUES (7,-2147483648);
INSERT INTO object_tools_acl (tool_id,user_id) VALUES (8,-2147483648);
INSERT INTO object_tools_acl (tool_id,user_id) VALUES (9,-2147483648);
INSERT INTO object_tools_acl (tool_id,user_id) VALUES (10,-2147483648);
INSERT INTO object_tools_acl (tool_id,user_id) VALUES (11,-2147483648);
INSERT INTO object_tools_acl (tool_id,user_id) VALUES (12,-2147483648);
INSERT INTO object_tools_acl (tool_id,user_id) VALUES (13,-2147483648);
INSERT INTO object_tools_acl (tool_id,user_id) VALUES (14,-2147483648);
INSERT INTO object_tools_acl (tool_id,user_id) VALUES (15,-2147483648);
INSERT INTO object_tools_acl (tool_id,user_id) VALUES (16,-2147483648);
INSERT INTO object_tools_acl (tool_id,user_id) VALUES (17,-2147483648);
INSERT INTO object_tools_acl (tool_id,user_id) VALUES (18,-2147483648);
INSERT INTO object_tools_acl (tool_id,user_id) VALUES (19,-2147483648);
INSERT INTO object_tools_acl (tool_id,user_id) VALUES (20,-2147483648);
INSERT INTO script_library (script_id,script_name,script_code)
 VALUES (1,'Filter::SNMP','sub main()' || x'0D'||x'0A' || '{' || x'0D'||x'0A' || '   return $1->isSNMP;' || x'0D'||x'0A' || '}' || x'0D'||x'0A');
INSERT INTO script_library (script_id,script_name,script_code)
 VALUES (2,'Filter::Agent','sub main()' || x'0D'||x'0A' || '{' || x'0D'||x'0A' || '   return $1->isAgent;' || x'0D'||x'0A' || '}' || x'0D'||x'0A');
INSERT INTO script_library (script_id,script_name,script_code)
 VALUES (3,'Filter::AgentOrSNMP','sub main()' || x'0D'||x'0A' || '{' || x'0D'||x'0A' || '   return $1->isAgent || $1->isSNMP;' || x'0D'||x'0A' || '}' || x'0D'||x'0A');
INSERT INTO script_library (script_id,script_name,script_code)
 VALUES (4,'DCI::SampleTransform','sub dci_transform()' || x'0D'||x'0A' || '{' || x'0D'||x'0A' || '   return $1 + 1;' || x'0D'||x'0A' || '}' || x'0D'||x'0A');
INSERT INTO images (guid, name, category, mimetype, protected) VALUES
  ('092e4b35-4e7c-42df-b9b7-d5805bfac64e', 'Service', 'Network Objects', 'image/png', 1);
INSERT INTO images (guid, name, category, mimetype, protected) VALUES
  ('1ddb76a3-a05f-4a42-acda-22021768feaf', 'ATM', 'Network Objects', 'image/png', 1);
INSERT INTO images (guid, name, category, mimetype, protected) VALUES
  ('7cd999e9-fbe0-45c3-a695-f84523b3a50c', 'Unknown', 'Network Objects', 'image/png', 1);
INSERT INTO images (guid, name, category, mimetype, protected) VALUES
  ('904e7291-ee3f-41b7-8132-2bd29288ecc8', 'Node', 'Network Objects', 'image/png', 1);
INSERT INTO images (guid, name, category, mimetype, protected) VALUES
  ('b314cf44-b2aa-478e-b23a-73bc5bb9a624', 'HSM', 'Network Objects', 'image/png', 1);
INSERT INTO images (guid, name, category, mimetype, protected) VALUES
  ('ba6ab507-f62d-4b8f-824c-ca9d46f22375', 'Server', 'Network Objects', 'image/png', 1);
INSERT INTO images (guid, name, category, mimetype, protected) VALUES
  ('bacde727-b183-4e6c-8dca-ab024c88b999', 'Router', 'Network Objects', 'image/png', 1);
INSERT INTO images (guid, name, category, mimetype, protected) VALUES
  ('f5214d16-1ab1-4577-bb21-063cfd45d7af', 'Printer', 'Network Objects', 'image/png', 1);
INSERT INTO images (guid, name, category, mimetype, protected) VALUES
  ('f9105c54-8dcf-483a-b387-b4587dfd3cba', 'Switch', 'Network Objects', 'image/png', 1);
COMMIT TRANSACTION;
